==> openGion6.3.8.5_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF71S.sql <==
/****************************************************************************/
/* GF71 ( 画面関連状態ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2015/09/17 15:31:10                                            */
/****************************************************************************/
CREATE TABLE GF71 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (   1 )                    NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      VARCHAR2 ( 256 )                                        /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     VARCHAR2 (  60 )                                        /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     VARCHAR2 ( 256 )                                        /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     VARCHAR2 (  14 )                                        /*  60 最終更新日   */
 , TAGNAME      VARCHAR2 (  30 )                                        /*  80 ﾀｸﾞ名称      */
 , TO_GAMENID   VARCHAR2 (  30 )                                        /*  90 先画面ID     */
 , HREF         VARCHAR2 ( 256 )                                        /* 100 ﾘﾝｸ先URL     */
 , TARGET       VARCHAR2 (  30 )                                        /* 110 ﾀｰｹﾞｯﾄ       */
 , CLM          VARCHAR2 (  30 )                                        /* 120 項目         */
 , P_KEYS       VARCHAR2 ( 500 )                                        /* 130 引数ｷｰ       */
 , P_VALS       VARCHAR2 ( 500 )                                        /* 140 引数値       */
 , USEGAMENID   VARCHAR2 (  20 )                                        /* 150 画面使用     */
 , USEREDIRECT  VARCHAR2 (  20 )                                        /* 160 ﾘﾀﾞｲﾚｸﾄ使用  */
 , TEXT_DATA    CLOB                                                    /* 170 ﾃｷｽﾄ         */
 , FGOMIT       VARCHAR2 (   1 )        DEFAULT '0' NOT NULL            /* 180 除外ﾌﾗｸﾞ     */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF71S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF71T00 
  BEFORE INSERT ON GF71
  FOR EACH ROW 
  BEGIN 
    SELECT GF71S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.0.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF71S.sql <==
/****************************************************************************/
/* GF71 ( 画面関連状態ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF71 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (   1 )                    NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      VARCHAR2 ( 256 )                                        /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     VARCHAR2 (  60 )                                        /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     VARCHAR2 ( 256 )                                        /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     VARCHAR2 (  14 )                                        /*  60 最終更新日   */
 , TAGNAME      VARCHAR2 (  30 )                                        /*  80 ﾀｸﾞ名称      */
 , TO_GAMENID   VARCHAR2 (  30 )                                        /*  90 先画面ID     */
 , HREF         VARCHAR2 ( 256 )                                        /* 100 ﾘﾝｸ先URL     */
 , TARGET       VARCHAR2 (  30 )                                        /* 110 ﾀｰｹﾞｯﾄ       */
 , CLM          VARCHAR2 (  30 )                                        /* 120 項目         */
 , P_KEYS       VARCHAR2 ( 500 )                                        /* 130 引数ｷｰ       */
 , P_VALS       VARCHAR2 ( 500 )                                        /* 140 引数値       */
 , USEGAMENID   VARCHAR2 (  20 )                                        /* 150 画面使用     */
 , USEREDIRECT  VARCHAR2 (  20 )                                        /* 160 ﾘﾀﾞｲﾚｸﾄ使用  */
 , TEXT_DATA    CLOB                                                    /* 170 ﾃｷｽﾄ         */
 , FGOMIT       VARCHAR2 (   1 )        DEFAULT '0' NOT NULL            /* 180 除外ﾌﾗｸﾞ     */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF71S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF71T00 
  BEFORE INSERT ON GF71
  FOR EACH ROW 
  BEGIN 
    SELECT GF71S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
